BridgeState class
Properties
-
data
→ Map<String, dynamic>
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
close()
→ void
-
Close the Bridge Instance AppWide
This simply clears the bridge
-
closeKey(String name)
→ void
-
Closes the data Access to a parsed Key value
-
closeKeyList(List<String> names)
→ void
-
Closes a list of Keys;
Usually to make sure the state of a form is not preserved
And all the entries return to their default set values
-
containsKey(String key)
→ bool
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
load(String name, dynamic slice, Type type, [bool forceType = false, bool override = true, bool exception = false])
→ void
-
Loads a parsed name slice pair into the memory
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
read(String name, dynamic initial, {bool forceType = false})
→ BridgeModel
-
Retrieves a previously saved bridge slice
Retrieves a previously saved bridge slice
-
readMap(String mapName, dynamic fieldKey, dynamic initial)
→ BridgeModel
-
reads a Map from Memory
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateMap(String sliceName, MapEntry mapEntry)
→ void
-
updates a Map on the bridge